/*
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling;

import org.teleal.cling.registry.Registry;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.transport.Router;
import org.teleal.cling.transport.spi.StreamClient;
import org.teleal.cling.transport.spi.StreamServer;
import org.teleal.cling.transport.spi.MulticastReceiver;
import org.teleal.cling.controlpoint.ControlPoint;
import org.teleal.cling.transport.spi.DatagramIO;
import org.teleal.cling.transport.spi.DatagramProcessor;
import org.teleal.cling.transport.spi.GENAEventProcessor;
import org.teleal.cling.transport.spi.SOAPActionProcessor;

/**
 * Primary interface of the Cling Core UPnP stack.
 * <p>
 * An implementation can either start immediately when constructed or offer an additional
 * method that starts the UPnP stack on-demand. Implementations are not required to be
 * restartable after shutdown.
 * </p>
 * <p>
 * Implementations are always thread-safe and can be shared and called concurrently.
 * </p>
 *
 * @author Christian Bauer
 */
public interface UpnpService {

    public UpnpServiceConfiguration getConfiguration();
    public ControlPoint getControlPoint();
    public ProtocolFactory getProtocolFactory();
    public Registry getRegistry();
    public Router getRouter();
    public void setRouter(Router r);
    public StreamClient getStreamClient();    
    public StreamServer getStreamServer();
    public MulticastReceiver getMulticastReceiver();
    public DatagramIO getDatagramIO();
    public  SOAPActionProcessor getSOAPActionProcessor();
    public GENAEventProcessor getGENAEventProcessor();    
    public DatagramProcessor getDatagramProcessor();
   
    /**
     * Stopping the UPnP stack.
     * <p>
     * Clients are required to stop the UPnP stack properly. Notifications for
     * disappearing devices will be multicasted, existing event subscriptions canceled.
     * </p>
     */
    public void shutdown();

}
