/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.teleal.cling.transport;
/*
 * Copyright (C) 2011 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.teleal.cling.UpnpServiceConfiguration;
import org.teleal.cling.model.NetworkAddress;
import org.teleal.cling.model.message.IncomingDatagramMessage;
import org.teleal.cling.model.message.OutgoingDatagramMessage;
import org.teleal.cling.model.message.StreamRequestMessage;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.model.message.UpnpMessage;
import org.teleal.cling.protocol.ProtocolCreationException;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.protocol.ReceivingAsync;
import org.teleal.cling.transport.spi.DatagramIO;
import org.teleal.cling.transport.spi.InitializationException;
import org.teleal.cling.transport.spi.MulticastReceiver;
import org.teleal.cling.transport.spi.NetworkAddressFactory;
import org.teleal.cling.transport.spi.StreamClient;
import org.teleal.cling.transport.spi.StreamServer;
// import org.teleal.cling.transport.spi.UpnpStream;
import org.teleal.cling.common.util.Exceptions;
import org.teleal.cling.transport.impl.MulticastReceiverConfigurationImpl;
import org.teleal.cling.transport.impl.StreamServerConfigurationImpl;
import org.teleal.cling.transport.impl.StreamClientConfigurationImpl;

import java.net.DatagramPacket;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Executor;
// import java.util.logging.Level;
// import java.util.logging.Logger;


/**
 * Default implementation of network message router.
 * <p>
 * Initializes and starts listening for data on the network immediately on construction.
 * </p>
 *
 * @author Christian Bauer
 */

public class ClientRouterImpl implements Router {

    public static UpnpServiceConfiguration configuration;
    protected final ProtocolFactory protocolFactory;

    private StreamClient streamClient;
    private final NetworkAddressFactory networkAddressFactory;

    private MulticastReceiver multicastReceiver = null;
    private DatagramIO datagramIO = null;
    private StreamServer streamServer = null;
    private Map<InetAddress, StreamServer> streamServers = new HashMap();
    private NetworkAddress StreamServerAddress = null; 
    private int StreamServerPort = 0;
    List<NetworkAddress> streamServerAddresses = new ArrayList();
    private InetAddress addr = null;
    private final NetworkInterface netif = null;
    private static StreamServerConfigurationImpl ssconfig = null;
    private static MulticastReceiverConfigurationImpl mrconfig = null;
    private final Router router = this;
    private Executor asyncExecutor = null;
    private Executor syncExecutor = null;
    private int streamBufferSizeKilobytes = 64;
    private Boolean streamTcpNoDelay = true;
    
    /**
     * Creates a {@link org.teleal.cling.transport.spi.NetworkAddressFactory} from the given
     * {@link org.teleal.cling.UpnpServiceConfiguration} and initializes listening services. First an instance
     * of {@link org.teleal.cling.transport.spi.MulticastReceiver} is bound to eatch network interface. Then
     * an instance of {@link org.teleal.cling.transport.spi.DatagramIO}
     * and {@link org.teleal.cling.transport.spi.StreamServer} is bound to each bind address
     * returned by the network address factory, respectively. There is only one instance of
     * {@link org.teleal.cling.transport.spi.StreamClient} created and managed by this router.
     *
     * @param configuration   The configuration used by this router.
     * @param protocolFactory The protocol factory used by this router.
     * @throws InitializationException When initialization of any listening network service fails.
     */
    public ClientRouterImpl(final UpnpServiceConfiguration configuration, final ProtocolFactory protocolFactory, final InetAddress addr)
            throws InitializationException {

        this.addr = addr;
        this.configuration = configuration;
        this.protocolFactory = protocolFactory;
        this.configuration.setLocalInetAddress(addr);
        this.configuration.setRouter(router);
        // Log.v("eXport-it router","Starting networking services...");
        networkAddressFactory = getConfiguration().createNetworkAddressFactory();
        this.asyncExecutor = this.configuration.getAsyncProtocolExecutor();
        this.syncExecutor = this.configuration.getSyncProtocolExecutor();        
        streamClient = this.configuration.createStreamClient();
        // multicastReceiver = this.configuration.createMulticastReceiver(networkAddressFactory, this.configuration, this.protocolFactory);
        datagramIO = this.configuration.createDatagramIO(networkAddressFactory, this.configuration, this.protocolFactory);
        if (datagramIO != null) {
           // Log.v("eXport-it router","execute datagramIO as a thread...");
           new Thread(datagramIO).start();  
        }         
    }

    @Override
    public UpnpServiceConfiguration getConfiguration() {
        return configuration;
    }

    @Override
    public ProtocolFactory getProtocolFactory() {
        return protocolFactory;
    }
    
    @Override
    public Executor getAsyncProtocolExecutor() {
        return asyncExecutor;
    }
    
    @Override
    public Executor getSyncProtocolExecutor() {
        return syncExecutor;
    }
    
    @Override
    public NetworkAddressFactory getNetworkAddressFactory() {
        return networkAddressFactory;
    }
    
    @Override
    public  MulticastReceiver getMulticastReceiver() {
        return multicastReceiver;
    }
    
    @Override
    public DatagramIO getDatagramIO() {
        return datagramIO;
    }

    @Override
    public StreamClient getStreamClient() {
        return streamClient;
    }
    
    @Override
    public StreamServer getStreamServer() {
        return streamServer;
    }
    
    protected Map<InetAddress, StreamServer> getStreamServers() {
        return streamServers;
    }
    
    @Override
    synchronized public List<NetworkAddress> getActiveStreamServers(InetAddress preferredAddress) {
        // Log.v("eXport-it router","Starting getActiveStreamServers.");
        List<NetworkAddress> streamServerAddresses = new ArrayList();

        /* StreamServer preferredServer;
        if (preferredAddress != null &&
                (preferredServer = getStreamServers().get(preferredAddress)) != null) {
            streamServerAddresses.add(
                    new NetworkAddress(
                            preferredAddress,
                            preferredServer.getPort(),
                            getNetworkAddressFactory().getHardwareAddress(preferredAddress)

                   )
            );
            return streamServerAddresses;
        }

        for (Map.Entry<InetAddress, StreamServer> entry : getStreamServers().entrySet()) {
            byte[] hardwareAddress = getNetworkAddressFactory().getHardwareAddress(entry.getKey());
            streamServerAddresses.add(
                    new NetworkAddress(entry.getKey(), entry.getValue().getPort(), hardwareAddress)
            );
        } */
       NetworkAddress activeStreamServer = null;
              // InetAddress addr = null;
              // try { addr = InetAddress.getByName("0.0.0.0"); } catch (UnknownHostException ex) {      }
              if (addr != null) {
                 activeStreamServer = new NetworkAddress(addr,49152);
              }  
              streamServerAddresses.add(activeStreamServer);
        return streamServerAddresses;
    }   
    
    @Override
    public StreamServer getActiveStreamServer() {
            return streamServer;
    }

   /**
     * Sends the UDP datagram on all bound {@link org.teleal.cling.transport.spi.DatagramIO}s.
     *
     * @param msg The UDP datagram message to send.
     */
    @Override
    public void sendAsync(OutgoingDatagramMessage msg) {
            datagramIO.sendAsync(msg);
    }   
    
    /**
     * Sends the TCP stream request with the {@link org.teleal.cling.transport.spi.StreamClient}.
     *
     * @param msg The TCP (HTTP) stream message to send.
     * @return The return value of the {@link org.teleal.cling.transport.spi.StreamClient#sendRequest(StreamRequestMessage)}
     *         method or <code>null</code> if no <code>StreamClient</code> is available.
     */
    @Override
    public StreamResponseMessage send(StreamRequestMessage msg) {
        if (getStreamClient() == null) {
            // log.fine("No StreamClient available, ignoring: " + msg);
            return null;
        }
        // log.fine("Sending via TCP unicast stream: " + msg);
        return getStreamClient().sendRequest((StreamRequestMessage)msg);
    }
    
    @Override
     synchronized public void shutdown() {
        // Log.v("eXport-it router","Shutting down network services");

        if (streamClient != null) {
            // Log.v("eXport-it router","Stopping stream client connection management/pool");
            streamClient.stop();
        }
        if (datagramIO != null) {
            // Log.v("eXport-it router","Stopping stream client connection management/pool");
            datagramIO.stop();
        } 
    }

    /**
     * Sends the given bytes as a broadcast on all bound {@link org.teleal.cling.transport.spi.DatagramIO}s,
     * using source port 9.
     * <p>
     * TODO: Support source port parameter
     * </p>
     *
     * @param bytes The byte payload of the UDP datagram.
     */
    @Override
    public void broadcast(byte[] bytes) {
            InetAddress broadcast = getNetworkAddressFactory().getMulticastGroup();
            if (broadcast != null) {
                // Log.v("eXport-it router","Sending UDP datagram to broadcast address: " + broadcast.getHostAddress());
                DatagramPacket packet = new DatagramPacket(bytes, bytes.length, broadcast, 1900);
                datagramIO.send(packet);
            }
    }
    
    public void IPAddressChanged () {
        datagramIO.stop();
        addr = configuration.getLocalInetAddress();
        datagramIO = this.configuration.createDatagramIO(networkAddressFactory, this.configuration, this.protocolFactory);
        if (datagramIO != null) {
           // Log.v("eXport-it router","execute datagramIO as a thread...");
           new Thread(datagramIO).start();  
        }   
    }  
    
}

