/*
 * Copyright (C) March 2020 Design & Development of Computerized Solutions, Belgium
 * program modified by Philippe Gillain for eXport-it application, removing Apache HTTP Client library requirement.
 *
 */
/** Using code from:
 * A simple, tiny, nicely embeddable HTTP 1.0 (partially 1.1) server in Java
 *
 * <p> NanoHTTPD version 1.27,
 * Copyright &copy; 2001,2005-2013 Jarno Elonen (elonen@iki.fi, http://iki.fi/elonen/)
 * and Copyright &copy; 2010 Konstantinos Togias (info@ktogias.gr, http://ktogias.gr)
 */
/* Developped from Teeal Cling code but removing Apache HTTP Client requirement
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.transport.impl;

// import android.util.Log;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.URLEncoder;
import java.net.URISyntaxException;
import java.util.Date;
import java.util.Enumeration;
import java.util.Vector;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Properties;
import java.util.StringTokenizer;
import java.util.TimeZone;
import java.io.ByteArrayOutputStream;
import java.io.FileOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.net.SocketAddress;
import java.net.SocketException;
import java.net.SocketTimeoutException;
import java.net.URI;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.text.SimpleDateFormat;
import java.util.Map;
import java.util.concurrent.Executor;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.zip.GZIPOutputStream;

import org.teleal.cling.common.io.IO;
import org.teleal.cling.model.message.StreamRequestMessage;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.model.message.UpnpHeaders;
import org.teleal.cling.model.message.UpnpMessage;
import org.teleal.cling.model.message.UpnpOperation;
import org.teleal.cling.model.message.UpnpRequest;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.message.header.ContentTypeHeader;
import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.cling.model.message.header.ServerHeader;
import org.teleal.cling.model.message.header.UpnpHeader;
import org.teleal.cling.protocol.ProtocolCreationException;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.protocol.ReceivingSync;
import org.teleal.cling.transport.Router;


/**
 * Handles one session, i.e. parses the HTTP request
 * and returns the response.
 */
public class HttpSession implements Runnable {
    
    private Socket mySocket = null;
    private static int theBufferSize = 64 * 1024;
    private static Router router;
    protected ProtocolFactory protocolFactory = null;
    protected ReceivingSync syncProtocol = null;
    
    /**
     * GMT date formatter
     */
    private static java.text.SimpleDateFormat gmtFrmt;
    static {
	gmtFrmt = new java.text.SimpleDateFormat( "E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
	gmtFrmt.setTimeZone(TimeZone.getTimeZone("GMT"));
    }
    public boolean keepAlive = true;
    /**
     * HTTP status code after processing, e.g. "200 OK", HTTP_OK
     */
    public String status = HTTP_OK;
    /**
     * MIME type of content, e.g. "text/html"
     */
    public String mimeType = DEFAULT_CONTENT_TYPE_UTF8;
    /**
     * Data of the response, may be null.
     */
    public InputStream data = null; 
    public String method = null;
    /**
     * Some HTTP response status codes
     */
    public static final String
		HTTP_OK = "200 OK",
		HTTP_PARTIALCONTENT = "206 Partial Content",
		HTTP_RANGE_NOT_SATISFIABLE = "416 Requested Range Not Satisfiable",
		HTTP_REDIRECT = "301 Moved Permanently",
		HTTP_NOTMODIFIED = "304 Not Modified",
		HTTP_FORBIDDEN = "403 Forbidden",
		HTTP_NOTFOUND = "404 Not Found",
		HTTP_BADREQUEST = "400 Bad Request",
		HTTP_INTERNALERROR = "500 Internal Server Error",
		HTTP_NOTIMPLEMENTED = "501 Not Implemented";
    /**
     * Common mime types for dynamic content
     */
    public static final String
		MIME_PLAINTEXT = "text/plain",
		MIME_HTML = "text/html",
		MIME_DEFAULT_BINARY = "application/octet-stream",
                DEFAULT_CONTENT_TYPE = "text/xml",
                DEFAULT_CONTENT_TYPE_UTF8 = "text/xml;charset=\"utf-8\"",
		MIME_XML = "text/xml";
                
    public HttpSession (Router router, Socket s) {
        this.router = router;
	mySocket = s;
	Thread t = new Thread( this );
	t.setDaemon( true );
	t.start();
    }
    
    @Override
    public void run() {
        
        final int bufsize = 8192;
	byte[] buf = new byte[bufsize];
	int splitbyte = 0;
	int rlen = 0;
        int read = 0;
        String host = "";
        int port = 0;
        String Rhost = "";
        String RAddress = "";
        int Rport = 0;
        String SoapAction = "";
        Boolean alreadyDone = false;
        StreamResponseMessage responseMsg = null;
        StreamRequestMessage requestMessage = null;
        UpnpOperation requestOperation;
        boolean KeepAlive = true;
        int loop = 0;
        String requestMethod = "";
        String requestURI = "";
        InputStream is = null;
        OutputStream out = null;
        InetAddress srv_addr = null;
	Properties pre = new Properties();
	Properties parms = new Properties();
	Properties header = new Properties();
	Properties files = new Properties();
        String line = "";
        String method = "";
	String uri = "";
        String uri2 = "";
        String version = "";
        String bodyString = "";
        byte[] bodyBytes;
        // ByteArrayOutputStream f = null;
        // InputStream data = null;
        int pending = 0;
        byte[] outbuf = null;
        String contentLength = "";
        String contentType = "";
        boolean soapActionFound = false;
        boolean contentLengthFound = false;
        boolean contentTypeFound = false;
        boolean requestHeadersReceived = false;
        boolean requestBodyReceived = false;
        int requestHeadersLength = 0;
        int requestBodyLength = 0;
        int requestContentLength = 0;
        
            // Log.v("eXport-it HttpSession","starting HttpSession!!!");
                    
            while (KeepAlive) {
                
                if (mySocket == null) {
                    // Log.v("eXport-it HttpSession ","mySocket is NULL!!! ");
                    KeepAlive = false;
                    return;
                }
                
                if (mySocket.isClosed()) {
                    // Log.v("eXport-it HttpSession ","mySocket is CLOSED!!! ");
                    KeepAlive = false;
                    return;
                }
                if (is == null) {
                    try {
                        is = mySocket.getInputStream();
                    } catch (IOException ioe) {
                        // Log.v("eXport-it HttpSession ","IOException in getInputStream: "+ioe);
                        KeepAlive = false;
                        return;
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession ","Exception in getInputStream: "+ex);
                        KeepAlive = false;
                        return;
                    }
                    try {
                        InetSocketAddress sockAddr = (InetSocketAddress) mySocket.getRemoteSocketAddress();
                        if (sockAddr != null) {
                            InetAddress Rip = sockAddr.getAddress();
                            Rhost = Rip.getHostAddress();
                            Rport = sockAddr.getPort();
                        }
                        // Log.v("eXport-it HttpSession ","Origin of Request: "+Rhost+":"+Rport);
                        RAddress = Rhost+":"+Rport;
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession ","Exception in getRemoteSocketAddress: "+ex);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                       return;
                    } 
                    try { 
                        srv_addr = mySocket.getLocalAddress();
                    } catch (IllegalStateException ex) {
                        // Log.v("eXport-it HttpSession ","Illegal State Exception in getLocalAddress:"+ex);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    } catch (Exception ex)  {
                        // Log.v("eXport-it HttpSession "," Exception in getLocalAddress: "+ex);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }  
                    if (srv_addr != null) {
                        host = srv_addr.getHostAddress();
                        port = mySocket.getLocalPort();
                    } else {
                        // Log.v("eXport-it HttpSession ","server address is NULL!!! ");
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }                   
                }
                if (is == null) {
                    // Log.v("eXport-it HttpSession ","InputStream is NULL!!! ");
                    KeepAlive = false;
                    return;
                }
                
	        pre = new Properties();
	        parms = new Properties();
	        header = new Properties();
	        files = new Properties();
                line = "";
                requestHeadersReceived = false;
                requestBodyReceived = false;
                requestHeadersLength = 0;
                requestBodyLength = 0;
                requestContentLength = 0;
            
	        // Decode the header into parms and header java properties
                splitbyte = 0;
		rlen = 0;
                buf = new byte[bufsize];
                read = 0;
                while (read == 0) {
                    try {
		        read = is.read(buf, 0, bufsize);
                    } catch (SocketException sex) {
                        /* if (sex != null) {
                            Log.v("eXport-it HttpSession ","SocketException reading initial buffer of request: "+sex+ " loop="+loop); 
                        } */
                        if (read == 0) {
                            if (is != null) {
                                try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;
                        }
	            } catch (IOException ioe) {
                         //  if InputStream is closed we have all data
                        if (ioe != null) {
                            // Log.v("eXport-it HttpSession ","IOException reading initial buffer of request: "+ioe+ " loop="+loop); 
                        }
                        if (read == 0) {
                            if (is != null) {
                                try { is.close(); } catch (IOException ex) {  }
                            }
                            KeepAlive = false;
                            return;
                        }
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession ","Exception reading initial buffer of request: "+ex+ " loop="+loop);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }
                }
		    while (read > 0) {
		        rlen += read;
                        if (rlen > bufsize) {
                            rlen = bufsize;
                        }
		        splitbyte = findHeaderEnd(buf, rlen);
		        if (splitbyte > 0) break;
                        if (rlen >= bufsize) {
                           if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                           }
                           KeepAlive = false;
                           return;
                        }
                        try {
		            read = is.read(buf, rlen, bufsize - rlen);
                        } catch (SocketException sex) {

	                } catch (IOException ioe) {

                        } catch (Exception ex) {
                           // Log.v("eXport-it HttpSession ","Exception reading next buffer of request: "+ex+ " loop="+loop);
                           if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                           }
                           KeepAlive = false;
                           return;
                        }    
		    }
                    
                    // Create a BufferedReader for parsing the header.
                    if (splitbyte < 1) { 
                        // Log.v("eXport-it HttpSession ","splitbyte is 0!!! ");
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }
                    requestHeadersReceived = true;
                    requestHeadersLength = splitbyte;
                    
                try {    
		    ByteArrayInputStream hbis = new ByteArrayInputStream(buf, 0, rlen);
		    BufferedReader hin = new BufferedReader( new InputStreamReader( hbis ), 32768);

	            // Read the request line
                    // Log.v("eXport-it HttpSession ","Read the request line ");
	            String inLine = hin.readLine();
	            if (inLine != null) {
	                StringTokenizer st = new StringTokenizer( inLine );
	                method = st.nextToken();
	                pre.put("method", method);
                        uri = st.nextToken();
                        uri2 = uri;
                        int qmi = uri.indexOf( '?' );
	                if ( qmi >= 0 ) {
		            decodeParms( uri.substring( qmi+1 ), parms );
		            uri = decodePercent( uri.substring( 0, qmi ));
	                } else uri = decodePercent(uri);
                        if (st.hasMoreTokens()) {
                            version = st.nextToken();
		            String line2 = hin.readLine();
		            while ( line2 != null && line2.trim().length() > 0 ) {
		                 int p = line2.indexOf( ':' );
		                 if ( p >= 0 ) {header.put( line2.substring(0,p).trim().toLowerCase(), line2.substring(p+1).trim()); }
		                 line2 = hin.readLine();
		            }
	                }
                    }
                    pre.put("uri", uri);
                    pre.put("uri2", uri2);
                    pre.put("version", version);
                } catch (SocketException sex) {    
	        } catch (IOException ioe) {
                    // Log.v("eXport-it HttpSession ","Exception processing request: "+ioe+ " loop="+loop);
                    if (is != null) {
                        try { is.close(); } catch (IOException ex) {  }
                    }
                    KeepAlive = false;
                    return;
                } catch (Exception ex) {
                    // Log.v("eXport-it HttpSession ","Exception processing request: "+ex+ " loop="+loop);
                    if (is != null) {
                        try { is.close(); } catch (IOException ioe) {  }
                    }
                    KeepAlive = false;
                    return;
                }

                if ((method == null) || (uri == null) || (method == "") || (uri == "")) {
                    if (is != null) {
                        try { is.close(); } catch (IOException ex) {  }
                    }
                    KeepAlive = false;
                    return;
                }
                // if (loop > 0) {
                //    Log.v("eXport-it HttpSession ","request from "+ Rhost + ":" + Rport + " loop="+loop+"method:"+method+" version: "+version+" uri: "+uri2);
                // } 
                String AV_Client = "";
                String AV_PhysicalUnit = "";
                SoapAction = "";
                soapActionFound = false;
                contentLengthFound = false;
                contentTypeFound = false;
                requestMethod = method;
                if (uri2 != null) {
                    if (uri2.length() > 2) {
                        requestURI = uri2;
                    } else {
                        requestURI = uri;
                    }
                } else {
                    requestURI = uri;
                }
                URI u = null;
                if (uri != null) {
                    try {
                        u = new URI(requestURI);
                    } catch (URISyntaxException uex) {
                        if (is != null) {
                            try { is.close(); } catch (IOException ex) {  }
                        }
                        KeepAlive = false;
                        return;
                    } catch (Exception ex) {
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }
                } 
                if (u == null) {
                    if (is != null) {
                        try { is.close(); } catch (IOException ioe) {  }
                    }
                    KeepAlive = false;
                    return;
                }
                KeepAlive = false;
                contentLength = "";
                contentType = "";
                if ( header != null ) {
                    // Log.v("eXport-it HttpSession ","request to "+ host + ": " + port + " "+uri+"\r\n");
		    Enumeration e = header.keys();
		    while ( e.hasMoreElements()) {
		        String key = (String)e.nextElement();
		        String value = header.getProperty( key );
                        if (key.toLowerCase().equals("connection")) {
                            if (value.toLowerCase().equals("keep-alive")) { 
                                if (requestMethod.toUpperCase().equals("POST")) {
                                    KeepAlive = true;
                                } 
                            }
                        } else {
                            if (key.toLowerCase().equals("content-length")) {
                                contentLength = value;
                                contentLengthFound = true;
                            } else {
                                if (key.toLowerCase().equals("soapaction")) {
                                    SoapAction = value;
                                    soapActionFound = true;
                                } else {
                                    if (key.toLowerCase().equals("content-type")) {
                                        contentType = value;
                                        contentTypeFound = true;
                                    }
                                }
                            }
                        }
		        // Log.v("eXport-it HttpSession ","request header "+ key + ": " + value);
		    }
                }
                if ( parms != null ) {
                    // Log.v("eXport-it HttpSession ","request from "+ host + ": " + port + " "+uri+"\r\n");
		    Enumeration p = parms.keys();
		    while ( p.hasMoreElements()) {
		        String key = (String)p.nextElement();
		        String value = parms.getProperty( key );
		        // Log.v("eXport-it HttpSession ","parm  "+ key + "=" + value + "\r\n");
		    }
                }    
	        int size = 0;
                requestContentLength = 0;
	        if (contentLengthFound) {
		    try { 
                        size = Integer.parseInt(contentLength);
                        requestContentLength = size;
                    } catch (NumberFormatException ex) {     }
	        }
                /* if (requestMethod.toUpperCase().equals("POST")) {
                    Log.v("eXport-it HttpSession "," content-size:"+contentLength+"  content-Type:"+contentType+"  SoapAction:"+SoapAction);
                } */
                // Now read all the body and write it to bodyString
                try {
                    // Write the part of body already read to ByteArrayOutputStream f
		    ByteArrayOutputStream f = new ByteArrayOutputStream();
		    if (splitbyte < rlen) f.write(buf, splitbyte, rlen-splitbyte);

		    // While Firefox sends on the first read all the data fitting
		    // our buffer, Chrome and Opera send only the headers even if
		    // there is data for the body. We do some magic here to find
		    // out whether we have already consumed part of body, if we
		    // have reached the end of the data to be sent or we should
		    // expect the first byte of the body at the next read.
		    if (splitbyte < rlen) size -= rlen-splitbyte;
		    else if (splitbyte==0) size = 0;

		    // Now read all the body and write it to f
		    buf = new byte[bufsize];
                    int totlength = rlen;
		    while ((rlen >= 0) && (size > 0)) {
			rlen = is.read(buf, 0, bufsize);
			size -= rlen;
                        totlength = totlength + rlen;
		        if (rlen > 0) f.write(buf, 0, rlen);
		    }
                    /* if (totlength > 0) {
                        is.mark(totlength);
                    } */
                    // Get the raw body as a byte []
		    bodyBytes = f.toByteArray();
                    // Log.v("eXport-it HttpSession "," request body received length:"+bodyBytes.length);
                    if (bodyBytes.length > 0) {
                        requestBodyLength = bodyBytes.length;
                        bodyString = f.toString( StandardCharsets.UTF_8.name()); 
                        requestBodyReceived = true;
                    } else {
                        bodyString = ""; 
                    }
                } catch (IOException ioe) {
                    // Log.v("eXport-it HttpSession ","IOException reading request body "+ioe);
                }
                /* if (requestMethod.toUpperCase().equals("POST")) {
                    Log.v("eXport-it HttpSession ","POST body:"+bodyString);
                } */
                try {
                    if (bodyString.length() > 0) {
                        // Log.v("eXport-it HttpSession ","request body: "+bodyString);
            	        requestMessage = new StreamRequestMessage(UpnpRequest.Method.getByHttpName(requestMethod), URI.create(requestURI),bodyString);
                    } else {
                        requestMessage = new StreamRequestMessage(UpnpRequest.Method.getByHttpName(requestMethod), URI.create(requestURI));
                    }
                } catch (IllegalArgumentException e) {
                    String msg = "Invalid request URI: " + requestURI + ": " + e.getMessage();
            	    // Log.v("eXport-it HttpSession ","StreamRequestMessage IllegalArgumentException "+msg);
                    // throw new HttpException(msg, e);
                }
            
                if (requestMessage != null) {
                    /* if (requestMethod.toUpperCase().equals("POST")) {
                          Log.v("eXport-it HttpSession "," POST request URI: " + uri);
                          for (final String name: header.stringPropertyNames()) {
                              Log.v("eXport-it HttpSession ","  POST request HDR: " + name + " " + header.getProperty( name ));
                          }
                    } */
                    UpnpHeaders upnpHeaders = new UpnpHeaders();
                    if (!requestMessage.getOperation().getMethod().equals(UpnpRequest.Method.UNKNOWN)) {
                        // HTTP version
                        int requestHttpMinorVersion = 0;   //  httpRequest.getHttpMinorVersion();
                        requestOperation = requestMessage.getOperation();
                        requestMessage.getOperation().setHttpMinorVersion(requestHttpMinorVersion);
                        // Headers
                        for (final String name: header.stringPropertyNames()) {
                            upnpHeaders.add(name, header.getProperty(name));
                            if (name.toLowerCase().contains("x-av-client-info")) {
                                AV_Client = header.getProperty( name );
                            } else {
                                if (name.toLowerCase().contains("x-av-physical-unit-info")) {
                                    AV_PhysicalUnit = header.getProperty( name );
                                } else {
                                }
                            }
	                    // Log.v("eXport-it HttpSession ","Request  HDR: '" + name + "' = ': " + header.getProperty( name )+"\r\n");
                        }
                        /* if (!upnpHeaders.containsKey(UpnpHeader.Type.HOST)) {
                               upnpHeaders.add("Host", host+":"+port);
                        } */
                        if (requestMethod.toUpperCase().equals("POST")) {
                            int lng = 0;
                            try {
                                byte[] BodyByte = bodyString.getBytes("UTF-8");
                                lng = BodyByte.length;
                            } catch (UnsupportedEncodingException e) {
                            }
                            if (!soapActionFound) {
                                upnpHeaders.add("SoapAction", "urn:schemas-upnp-org:service:ContentDirectory:1#Browse");
                            }
                            if (!contentTypeFound) {
                                upnpHeaders.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                            }
                            if (!contentLengthFound) {
                                upnpHeaders.add("Content-Length", String.valueOf(lng));
                            }
                            // Log.v("eXport-it HttpSession ","request body length: "+bodyString.length()+"/"+lng+" content-length:"+contentLength);
                            // Log.v("eXport-it HttpSession "," POST request Body "+bodyString);
                        } 
                        
                        requestMessage.setHeaders(upnpHeaders);
                        // Body
                        requestMessage.setBody(UpnpMessage.BodyType.STRING, bodyString);
                        
                        if (bodyString.contains("X_GetFeatureList")==true) {
                            String responseText = getFeatureList();
                            UpnpHeaders headers = new UpnpHeaders();
                            headers.add(UpnpHeader.Type.SERVER, new ServerHeader());
                            headers.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                            headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                            String HeadersStr = headers.toString();
                            byte[] headerBytes = null;
                            try {
                                headerBytes = HeadersStr.getBytes("UTF-8");      // @@@  ()
                            } catch (UnsupportedEncodingException uee) {
                                // Log.v("eXport-it HttpSession ","UnsupportedEncodingException in HeadersStr.getBytes: "+uee);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }   catch (Exception ex) {
                                // Log.v("eXport-it HttpSession ","Exception in HeadersStr.getBytes: "+ex);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }
                            if (headerBytes == null) {
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }   
                            ByteArrayInputStream inputStr;
                            inputStr = new ByteArrayInputStream(headerBytes);    // bodyBytes2
                            headers = new UpnpHeaders(inputStr);
                            String headersString = headers.toString();
                            String responseEntity = responseText;
                            responseMsg = new StreamResponseMessage(responseText);
                            HeaderUtil.add(responseMsg, headers); 
                            alreadyDone = true;
                        } else {
                            if (bodyString.contains("X_SetBookmark")==true) {
                                String responseText = SetBookmark();
                                UpnpHeaders headers = new UpnpHeaders();
                                headers.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                                headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                                String HeadersStr = headers.toString();
                                byte[] headerBytes = null;
                                try {
                                    headerBytes = HeadersStr.getBytes("UTF-8");      // @@@  ()
                                } catch (UnsupportedEncodingException uee) {
                                    // Log.v("eXport-it HttpSession ","UnsupportedEncodingException in HeadersStr.getBytes: "+uee);
                                    if (is != null) {
                                        try { is.close(); } catch (IOException ioe) {  }
                                    }
                                    KeepAlive = false;
                                    return;
                                }   catch (Exception ex) {
                                    // Log.v("eXport-it HttpSession ","Exception in HeadersStr.getBytes: "+ex);
                                    if (is != null) {
                                        try { is.close(); } catch (IOException ioe) {  }
                                    }
                                    KeepAlive = false;
                                    return;
                                }
                                if (headerBytes == null) {
                                    if (is != null) {
                                        try { is.close(); } catch (IOException ioe) {  }
                                    }
                                    KeepAlive = false;
                                    return;
                                }
                                ByteArrayInputStream inputStr;
                                inputStr = new ByteArrayInputStream(headerBytes);    // bodyBytes2
                                headers = new UpnpHeaders(inputStr);
                                responseMsg = new StreamResponseMessage(responseText);
                                HeaderUtil.add(responseMsg, headers);
                                alreadyDone = true;                          
                            } else {
                                /* if ((AV_PhysicalUnit.length() > 1) && (AV_Client.length() > 1)) {
                                    String responseText = SetBookmark();
                                    UpnpHeaders headers = new UpnpHeaders();
                                    headers.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                                    headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                                    String HeadersStr = headers.toString();
                                    byte[] headerBytes;
                                    headerBytes = HeadersStr.getBytes("UTF-8");      
                                    ByteArrayInputStream inputStr;
                                    inputStr = new ByteArrayInputStream(headerBytes);    
                                    headers = new UpnpHeaders(inputStr);
                                    responseMsg = new StreamResponseMessage(responseText);
                                    HeaderUtil.add(responseMsg, headers);
                                    alreadyDone = true;      
                                } */              
                            } 
                        }                     

                        // Finally process it
                        if (!alreadyDone) {            
                        try {
                            /* UpnpHeaders upnpHeaders2 = requestMessage.getHeaders();
                            if (!upnpHeaders2.containsKey(UpnpHeader.Type.CONTENT_TYPE)) {
                                upnpHeaders2.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                                // upnpHeaders2.add(UpnpHeader.Type.SERVER, new ServerHeader());
                                // upnpHeaders2.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                            } */
                            requestMessage.setHeaders(upnpHeaders);
                            responseMsg = process(requestMessage);
                        } catch (RuntimeException ex) {
                            // Log.v("eXport-it HttpSession","Exception occured during UPnP stream processing: " + ex);
                            if (is != null) {
                                try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;
                        }
                    } 
                    if (responseMsg == null) {
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }
                    loop++;

                    int udaMajorVersion = 1;
                    int udaMinorVersion = 0;
                    UpnpOperation operation = requestOperation;
                    UpnpHeaders headers = new UpnpHeaders();
                    Object body;
                    UpnpMessage.BodyType bodyType = responseMsg.getBodyType();
                    operation = responseMsg.getOperation();
                    Properties pre2 = new Properties();
	            Properties parms2 = new Properties();
	            Properties header2 = new Properties();
	            Properties files2 = new Properties();
                    int statuscode = 200;
                    String statusMsg = "OK";
                    String bodyString2 = "";
                    byte[] bodyBytes2 = new byte[bufsize];

                       statuscode = responseMsg.getOperation().getStatusCode();
                       statusMsg = responseMsg.getOperation().getStatusMessage();
                       // Log.v("eXport-it HttpSession","Response RC: " + statuscode + "status Msg: " + statusMsg);
                       headers = responseMsg.getHeaders();
                       /* if (!headers.containsKey(UpnpHeader.Type.CONTENT_TYPE)) {
                           // Log.v("eXport-it HttpSession","Response NO Content-Type");
                           headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                       } */
                       if (!headers.containsKey(UpnpHeader.Type.SERVER)) {
                           // Log.v("eXport-it HttpSession","Response NO Server");
                           headers.add(UpnpHeader.Type.SERVER, new ServerHeader());
                        } 
                        // if (!headers.containsKey(UpnpHeader.Type.EXT)) {
                           // Log.v("eXport-it HttpSession","Response NO Ext");
                        //   headers.add(UpnpHeader.Type.EXT, new EXTHeader());
                        //}    
                        bodyType = responseMsg.getBodyType();
                        // Log.v("eXport-it HttpSession","Response to "+requestMessage.getUri().toString()+"bodyType: "+bodyType+" headers: "+headers.size());
                        if (responseMsg.hasBody()) {
                            if (responseMsg.getBodyType() == UpnpMessage.BodyType.STRING) {
                               bodyString2 = responseMsg.getBodyString();
                               if (bodyString2 == null) {
                                   bodyString2 = "";
                               }
                            } else {
                               bodyBytes2 = responseMsg.getBodyBytes();
                               if (bodyBytes2 == null) {
                                   bodyBytes2 = new byte[0];
                               }
                            }
                        }
                        udaMajorVersion = responseMsg.getUdaMajorVersion();
                        udaMinorVersion = responseMsg.getUdaMinorVersion();
                        if ((mySocket == null) || (mySocket.isClosed())) {
                            KeepAlive = false;
                            return;
                        } 
                        if (out == null) {
                            try {
                                out = mySocket.getOutputStream();
                            } catch (IOException ioe) {
                                // Log.v("eXport-it HttpSession ","IOException in getOutputStream: "+ioe);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ex) {  }
                                }
                                KeepAlive = false;
                                return;
                            }   catch (Exception ex) {
                                // Log.v("eXport-it HttpSession ","Exception in getOutputStream: "+ex);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }
                        }
                        if (out == null) {
                            if (is != null) {
                                try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;
                        }
	                // PrintWriter pw = new PrintWriter( out );
                        // BufferedWriter bw = null;
                        PrintWriter pw = null;
                        try {
                            // bw = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
                           // bw = new PrintStream(out, false,"UTF-8");
                           OutputStreamWriter osw = new OutputStreamWriter(out, "UTF-8");
                           BufferedWriter bw = new BufferedWriter(osw, 32768);
                           pw = new PrintWriter(bw,true);
                        } catch (UnsupportedEncodingException uee) {
                            // Log.v("eXport-it HttpSession"," UnsupportedEncodingException creating PrintStream "+uee);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return; 
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession"," Exception creating PrintWriter "+ex);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;  
                        }
                        if (pw == null) {
                            // Log.v("eXport-it HttpSession"," Buffered Print Writer pw is NULL!!!");
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;  
                        }
                        try {
		            pw.print("HTTP/1."+udaMinorVersion+" " + statuscode + " " + statusMsg + " \r\n");
		            java.text.SimpleDateFormat gmtFrmt = null;
                            gmtFrmt = new java.text.SimpleDateFormat( "E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
	                    gmtFrmt.setTimeZone(TimeZone.getTimeZone("GMT"));
                            if (gmtFrmt != null) {
                               pw.print( "Date: " + gmtFrmt.format( new Date()) + "\r\n");
                            }
                            String HeadersStr = "";
		            if (headers != null ) {
                                HeadersStr = headers.toString();
                                /* if (requestMethod.toUpperCase().equals("POST")) {
                                    Log.v("eXport-it HttpSession","Response Headers: "+HeadersStr);
                                } */
	                    }
                            pw.print(HeadersStr);
                            if (KeepAlive) {
                                pw.print("Connection: keep-alive\r\n");
                            } else {
                               pw.print("Connection: close\r\n");
                            }
                            // bw.print("Content-Type: text/xml; charset=UTF-8\r\n");
                            if (SoapAction != null) {
                                if (SoapAction.length() > 1) {
                                    pw.print("SOAPAction: " + SoapAction + "\r\n");
                                    // Log.v("eXport-it HttpSession","Response Headers: "+"SOAPAction: " + SoapAction);
                                } 
                            }
                            int lng =  0;
                            byte[] BodyBytes = new byte[100];
                            if (bodyString2 != null) {
                                if (bodyString2.length() > 0) {
                                    try {
                                        BodyBytes = bodyString2.getBytes("UTF-8");
                                        lng = BodyBytes.length + 2;
                                    } catch (UnsupportedEncodingException e) {
                                        // Log.v("eXport-it HttpSession","Response Body Length EncodingException: "+e);
                                        KeepAlive = false;
                                        return;
                                    }
                                    pw.print("Content-Length: "+lng + "\r\n");
                                    // Log.v("eXport-it HttpSession","Response Headers: "+"Content-Length: "+lng);
                                } else {
                                    if (bodyBytes2.length > 0) {
                                        BodyBytes = bodyBytes2;
                                        lng = BodyBytes.length + 2;
                                        try {
                                            bodyString2 = new String(bodyBytes2, "UTF-8");
                                        } catch (UnsupportedEncodingException uee) {
                                            // Log.v("eXport-it HttpSession","Response Body Bytes EncodingException: "+uee);
                                            KeepAlive = false;
                                            return;
                                        }
                                        if (lng > 0) {
                                            pw.print("Content-Length: "+lng + "\r\n");
                                            // Log.v("eXport-it HttpSession","Response Headers: "+"Content-Length: "+lng);
                                        } else {
                                            pw.print("Content-Length: 0\r\n");
                                        }
                                    }  
                                }
                                pw.print("user-agent: Linux/3.18.91-14843133-QB28034466 UPnP/1.0 DLNADOC/1.50 eXport-it/1.0\r\n");
                                pw.print("\r\n");
                                if (lng > 0) {
                                    pw.print(bodyString2);
                                    pw.print("\r\n");
                                    /* if (requestMethod.toUpperCase().equals("POST")) {
                                        Log.v("eXport-it HttpSession","Response Body length: "+bodyString2.length()+"/"+lng+" "+bodyString2);
                                    } */
                                }
                            } else {
		                pw.print("\r\n");
                            }
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession ","Exception in writing pw: "+ex);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;    
                        }   
                        // Log.v("eXport-it HttpSession","Response RC: " + statuscode + " status Msg: " + statusMsg+"  body length: "+bodyString2.length());
                        try {
                            pw.flush();
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession ","Exception in flushing pw: "+ex);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;    
                        }   
                        if (!KeepAlive) {
                            try {
                                if (requestMethod.toUpperCase().equals("POST")) {
                                    try {
                                        Thread.sleep(3000);
                                    } catch (InterruptedException iex) {
                                    }
                                } else {
                                    try {
                                        Thread.sleep(1000);
                                    } catch (InterruptedException iex) {
                                    }
                                }
                                if (pw != null) pw.close();
                                if (out != null) out.close();
                            } catch (IOException ioe) {
                                // Log.v("eXport-it HttpSession ","IOException in closing out: "+ioe);
                                KeepAlive = false;
                                return;    
                            } catch (Exception ex) {
                                // Log.v("eXport-it HttpSession "," Exception closing out: "+ex);
                                KeepAlive = false;
                                return;   
                            }
                        }
                    }
                }

                if (!KeepAlive) {
                    try {
	                if (is != null) {
                            if (requestMethod.toUpperCase().equals("POST")) {
                                try {
                                    Thread.sleep(3000);
                                } catch (InterruptedException iex) {
                                }
                            } else {
                                try {
                                    Thread.sleep(1000);
                                } catch (InterruptedException iex) {
                                }
                            }
                            is.close();
                        }
                    } catch (IOException ioe) {
                        // Log.v("eXport-it HttpSession ","IOException in closing in: "+ioe);
                        KeepAlive = false;
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession "," Exception closing in: "+ex);
                        KeepAlive = false;
                    }
                    if ((mySocket != null) && (!mySocket.isClosed())) {
                            if (requestMethod.toUpperCase().equals("POST")) {
                                try {
                                    Thread.sleep(2000);
                                } catch (InterruptedException iex) {
                                }
                            } else {
                                try {
                                    Thread.sleep(1000);
                                } catch (InterruptedException iex) {
                                }
                            }
	                try { mySocket.close(); } catch(Exception ex2) {
                            KeepAlive = false;
                        } 
                    }   
                } else {
                    try {
                       Thread.sleep(100);
                    } catch (InterruptedException iex) {
                        
                    }
                }
            }
           
 
        if (mySocket != null) {
            if (!mySocket.isClosed()) {
                try {
                    Thread.sleep(1000);
                    mySocket.close();
                } catch (InterruptedException iex) {
                } catch (Exception ex) { }
            }
        }
        return;
        
    }    

    /**
     * Find byte index separating header from body.
     * It must be the last byte of the first two sequential new lines.
     **/
    private int findHeaderEnd(final byte[] buf, int rlen) {
	int splitbyte = 0;
        if (buf.length < rlen) { rlen = buf.length; }
	while (splitbyte + 3 < rlen) 	{
	    if (buf[splitbyte] == '\r' && buf[splitbyte + 1] == '\n' && buf[splitbyte + 2] == '\r' && buf[splitbyte + 3] == '\n') {
		return splitbyte + 4;
	    }	
	    splitbyte++;
	}
	return 0;
    }

    /**
     * Decodes the percent encoding scheme. <br/>
     * For example: "an+example%20string" -> "an example string"
     */
    private String decodePercent( String str ) {
	try {		
            StringBuffer sb = new StringBuffer();
	    for( int i=0; i<str.length(); i++ ) {
		char c = str.charAt( i );
		switch ( c ) {
		    case '+':
			sb.append( ' ' );
			break;
		    case '%':
			sb.append((char)Integer.parseInt( str.substring(i+1,i+3), 16 ));
			i += 2;
			break;
		    default:
			sb.append( c );
		        break;
		}
	    }
	    return sb.toString();
	} catch( Exception e) {
	    // sendError( HTTP_BADREQUEST, "BAD REQUEST: Bad percent-encoding." );
	    return null;
	}
    }

    /**
     * Decodes parameters in percent-encoded URI-format
     * ( e.g. "name=Jack%20Daniels&pass=Single%20Malt" ) and
     * adds them to given Properties. NOTE: this doesn't support multiple
     * identical keys due to the simplicity of Properties -- if you need multiples,
     * you might want to replace the Properties with a Hashtable of Vectors or such.
     */
    private void decodeParms( String parms, Properties p ) {
	if ( parms == null ) {
		return;
        }
	StringTokenizer st = new StringTokenizer( parms, "&" );
	while ( st.hasMoreTokens()) {
		String e = st.nextToken();
		int sep = e.indexOf( '=' );
		if ( sep >= 0 ) {
			p.put( decodePercent( e.substring( 0, sep)).trim(), decodePercent( e.substring( sep+1)));
		} else {
			p.put( decodePercent( e ).trim(), "" );
		}	
	}
    }
    
    /**
     * URL-encodes everything between "/"-characters. Encodes spaces as '%20'
     * instead of '+'.
     */
    private String encodeUri(String uri) {
        String newUri = "";
        StringTokenizer st = new StringTokenizer(uri, "/ ", true);
        while (st.hasMoreTokens()) {
            String tok = st.nextToken();
            if (tok.equals("/")) {
                newUri += "/";
            } else if (tok.equals(" ")) {
                newUri += "%20";
            } else {
                // newUri += URLEncoder.encode(tok);
                try { newUri += URLEncoder.encode( tok, "UTF-8" ); } catch ( java.io.UnsupportedEncodingException uee ) {}
                // For Java 1.4 you'll want to use this instead:
                // try { newUri += URLEncoder.encode( tok, "UTF-8" ); } catch ( java.io.UnsupportedEncodingException uee ) {}
            }
        }
        return newUri;
    }   
    
    synchronized public StreamResponseMessage process(StreamRequestMessage requestMsg) {
        // Log.v("eXport-it HttpSession","Processing stream request message: " + requestMsg);
        
        try {
            // Try to get a protocol implementation that matches the request message
            syncProtocol = router.getProtocolFactory().createReceivingSync(requestMsg);
        } catch (Exception ex) {
            // Log.v("eXport-it HttpSession","Exception for defining synchronous message processing: " + ex);
        }            
        // Log.v("eXport-it HttpSession","Running protocol for synchronous message processing: " + syncProtocol);
        syncProtocol.run();

        // ... then grab the response
        StreamResponseMessage responseMsg = syncProtocol.getOutputMessage();

        if (responseMsg == null) {
            // That's ok, the caller is supposed to handle this properly (e.g. convert it to HTTP 404)
            // Log.v("eXport-it HttpSession","Protocol did not return any response message");
            return null;
        }
        // Log.v("eXport-it HttpSession","Protocol returned response: " + responseMsg);
        return responseMsg;
    }
        
    public String getFeatureList() {
        String resp ="<s:Envelope xmlns:s=\"http://schemas.xmlsoap.org/soap/envelope/\" s:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"+
            "<s:Body>"+
            "<u:X_GetFeatureListResponse xmlns:u=\"urn:schemas-upnp-org:service:ContentDirectory:1\">"+
            "<FeatureList>"+
            "<?xml version=\"1.0\" encoding=\"utf-8\"?>\r\n"+
            "&lt;Features xmlns=\"urn:schemas-upnp-org:av:avs\""+
            " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""+
            " xsi:schemaLocation=\"urn:schemas-upnp-org:av:avs http://www.upnp.org/schemas/av/avs.xsd\"&gt;"+
            "&lt;Feature name=\"samsung.com_BASICVIEW\" version=\"1\"&gt;"+
            "&lt;container id=\"1\" type=\"object.item.videoItem\"/&gt;"+             
            "&lt;container id=\"2\" type=\"object.item.audioItem\"/&gt;"+
            "&lt;container id=\"3\" type=\"object.item.imageItem\"/&gt;"+
            "&lt;/Feature&gt;"+
            "</FeatureList></u:X_GetFeatureListResponse>"+
            "</s:Body>"+
            "</s:Envelope>";
        return resp;
    }       
    
    public String SetBookmark() {
        String resp = "<s:Envelope xmlns:s=\"http://schemas.xmlsoap.org/soap/envelope/\" s:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"+
            "<s:Body>"+
            "<u:X_SetBookmarkResponse"+
            " xmlns:u=\"urn:schemas-upnp-org:service:ContentDirectory:1\">"+
            "</u:X_SetBookmarkResponse> 1 1"+
            "</s:Body>"+
            "</s:Envelope>";    
        return resp;
    } 

    public InputStream getData() {
        return this.data;
    }

    public String getMimeType() {
        return this.mimeType;
    }

    public String getRequestMethod() {
        return this.method;
    }

    public void setKeepAlive(boolean useKeepAlive) {
        this.keepAlive = useKeepAlive;
    }

    public void setData(InputStream data) {
        this.data = data;
    }

    public void setMimeType(String mimeType) {
        this.mimeType = mimeType;
    }

    public void setRequestMethod(String requestMethod) {
        this.method = requestMethod;
    }

    public void setStatus(String status) {
        this.status = status;
    }
    
}
  
