/*
 * Copyright (C) March 2020 Design & Development of Computerized Solutions, Belgium
 * program modified by Philippe Gillain for eXport-it application, removing Apache HTTP Client library requirement.
 *
 */
/** Using code from:
 * A simple, tiny, nicely embeddable HTTP 1.0 (partially 1.1) server in Java
 *
 * <p> NanoHTTPD version 1.27,
 * Copyright &copy; 2001,2005-2013 Jarno Elonen (elonen@iki.fi, http://iki.fi/elonen/)
 * and Copyright &copy; 2010 Konstantinos Togias (info@ktogias.gr, http://ktogias.gr)
 */
/* Developped from Teeal Cling code but removing Apache HTTP Client requirement
 * Copyright (C) 2010 Teleal GmbH, Switzerland
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.teleal.cling.transport.impl;

// import android.util.Log;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.URLEncoder;
import java.net.URISyntaxException;
import java.util.Date;
import java.util.Enumeration;
import java.util.Vector;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Properties;
import java.util.StringTokenizer;
import java.util.TimeZone;
import java.io.ByteArrayOutputStream;
import java.io.FileOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.net.SocketAddress;
import java.net.SocketException;
import java.net.SocketTimeoutException;
import java.net.URI;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.text.SimpleDateFormat;
import java.util.Map;
import java.util.concurrent.Executor;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.zip.GZIPOutputStream;
import org.teleal.cling.common.http.Headers;

import org.teleal.cling.common.io.IO;
import org.teleal.cling.model.message.StreamRequestMessage;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.model.message.UpnpHeaders;
import org.teleal.cling.model.message.UpnpMessage;
import org.teleal.cling.model.message.UpnpOperation;
import org.teleal.cling.model.message.UpnpRequest;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.message.header.ContentTypeHeader;
import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.cling.model.message.header.ServerHeader;
import org.teleal.cling.model.message.header.UpnpHeader;
import org.teleal.cling.protocol.ProtocolCreationException;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.protocol.ReceivingSync;
import org.teleal.cling.transport.Router;


/**
 * Handles one session, i.e. parses the HTTP request
 * and returns the response.
 */
public class HttpSession2 implements Runnable {
    
    private Socket mySocket = null;
    private static int theBufferSize = 64 * 1024;
    private static Router router;
    protected ProtocolFactory protocolFactory = null;
    protected ReceivingSync syncProtocol = null;
    
    /**
     * GMT date formatter
     */
    private static java.text.SimpleDateFormat gmtFrmt;
    static {
	gmtFrmt = new java.text.SimpleDateFormat( "E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
	gmtFrmt.setTimeZone(TimeZone.getTimeZone("GMT"));
    }
    public boolean keepAlive = true;
    /**
     * HTTP status code after processing, e.g. "200 OK", HTTP_OK
     */
    public String status = HTTP_OK;
    /**
     * MIME type of content, e.g. "text/html"
     */
    public String mimeType = DEFAULT_CONTENT_TYPE_UTF8;
    /**
     * Data of the response, may be null.
     */
    public InputStream data = null; 
    public String method = null;
    /**
     * Some HTTP response status codes
     */
    public static final String
		HTTP_OK = "200 OK",
		HTTP_PARTIALCONTENT = "206 Partial Content",
		HTTP_RANGE_NOT_SATISFIABLE = "416 Requested Range Not Satisfiable",
		HTTP_REDIRECT = "301 Moved Permanently",
		HTTP_NOTMODIFIED = "304 Not Modified",
		HTTP_FORBIDDEN = "403 Forbidden",
		HTTP_NOTFOUND = "404 Not Found",
		HTTP_BADREQUEST = "400 Bad Request",
		HTTP_INTERNALERROR = "500 Internal Server Error",
		HTTP_NOTIMPLEMENTED = "501 Not Implemented";
    /**
     * Common mime types for dynamic content
     */
    public static final String
		MIME_PLAINTEXT = "text/plain",
		MIME_HTML = "text/html",
		MIME_DEFAULT_BINARY = "application/octet-stream",
                DEFAULT_CONTENT_TYPE = "text/xml",
                DEFAULT_CONTENT_TYPE_UTF8 = "text/xml;charset=\"utf-8\"",
		MIME_XML = "text/xml";
                
    public HttpSession2 (Router router, Socket s) {
        this.router = router;
	mySocket = s;
	Thread t = new Thread( this );
	t.setDaemon( true );
	t.start();
    }
    
    @Override
    public void run() {
        
        final int bufsize = 8192;
	byte[] buf = new byte[bufsize];
	int splitbyte = 0;
	int rlen = 0;
        int read = 0;
        String host = "";
        int port = 0;
        String Rhost = "";
        String RAddress = "";
        int Rport = 0;
        String SoapAction = "";
        Boolean alreadyDone = false;
        StreamResponseMessage responseMsg = null;
        StreamRequestMessage requestMessage = null;
        UpnpOperation requestOperation = null;
        boolean KeepAlive = true;
        int loop = 0;
        String requestMethod = "";
        String requestURI = "";
        InputStream is = null;
        OutputStream out = null;
        BufferedReader br = null;
        InetAddress srv_addr = null;
        String line = "";
        String method = "";
	String uri = "";
        String uri2 = "";
        String version = "";
        String bodyString = "";
        byte[] bodyBytes;
        // ByteArrayOutputStream f = null;
        // InputStream data = null;
        int pending = 0;
        byte[] outbuf = null;
        String contentLength = "";
        String contentType = "";
        boolean soapActionFound = false;
        boolean contentLengthFound = false;
        boolean contentTypeFound = false;
        boolean requestHeadersReceived = false;
        boolean requestBodyReceived = false;
        int requestHeadersLength = 0;
        int requestBodyLength = 0;
        int requestContentLength = 0;
        int lineNb = 0;
        String statusLine = "";
        String HttpVersion = "";
        boolean no_request = false;
        boolean connectionFound = false;
        String headerKey  = "";
        String headerValue  = "";
        String applicationUrl = "";
        UpnpHeaders reqHeaders = new UpnpHeaders();
        UpnpHeaders upnpHeaders = new UpnpHeaders();
        int requestHttpMinorVersion = 0;   
        
            // Log.v("eXport-it HttpSession","starting HttpSession!!!");
                    
            while (KeepAlive) {
                
                if (mySocket == null) {
                    // Log.v("eXport-it HttpSession ","mySocket is NULL!!! ");
                    KeepAlive = false;
                    return;
                }
                
                if (mySocket.isClosed()) {
                    // Log.v("eXport-it HttpSession ","mySocket is CLOSED!!! ");
                    KeepAlive = false;
                    return;
                }
                if (is == null) {
                    try {
                        is = mySocket.getInputStream();
                        if (is == null) {
                            // Log.v("eXport-it HttpSession ","InputStream is NULL!!! ");
                            KeepAlive = false;
                            return;
                        }
                        InputStreamReader isr = new InputStreamReader(is, "UTF-8");
                        br = new BufferedReader(isr);
                    } catch (IOException ioe) {
                        // Log.v("eXport-it HttpSession ","IOException in getInputStream: "+ioe);
                        KeepAlive = false;
                        return;
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession ","Exception in getInputStream: "+ex);
                        KeepAlive = false;
                        return;
                    }
                    try {
                        InetSocketAddress sockAddr = (InetSocketAddress) mySocket.getRemoteSocketAddress();
                        if (sockAddr != null) {
                            InetAddress Rip = sockAddr.getAddress();
                            Rhost = Rip.getHostAddress();
                            Rport = sockAddr.getPort();
                        }
                        // Log.v("eXport-it HttpSession ","Origin of Request: "+Rhost+":"+Rport);
                        RAddress = Rhost+":"+Rport;
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession ","Exception in getRemoteSocketAddress: "+ex);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                       return;
                    } 
                    try { 
                        srv_addr = mySocket.getLocalAddress();
                    } catch (IllegalStateException ex) {
                        // Log.v("eXport-it HttpSession ","Illegal State Exception in getLocalAddress:"+ex);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    } catch (Exception ex)  {
                        // Log.v("eXport-it HttpSession "," Exception in getLocalAddress: "+ex);
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }  
                    if (srv_addr != null) {
                        host = srv_addr.getHostAddress();
                        port = mySocket.getLocalPort();
                    } else {
                        // Log.v("eXport-it HttpSession ","server address is NULL!!! ");
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }                   
                }
                if (br != null) {     
                    // Log.v("eXport-it HttpSession","getting Request message ");
                    line = null;
                    int line_length = 0;
                    int r = 0;
                    while ((line_length < 10) && ( r < 5)) {
                        try {
                            line = br.readLine();
                            r++;
                            if (line == null) {
                                line_length = 0;
                            } else {
                                line_length = line.length();
                            }
                        } catch (SocketException sex) {
                            // Log.v("eXport-it HttpSession","SocketException InputStream waiting for input on request: "+sex);  // Connection Reset !!!
                            if (line == null) {
                                KeepAlive = false;
                                return;
                            } else {
                                if (line.length() == 0) { 
                                   if (is != null) {
                                       try { is.close(); } catch (IOException ioe) {  }
                                   }
                                   KeepAlive = false;
                                   return;
                                } else {
                                    // Log.v("eXport-it HttpSession","SocketException InputStream waiting for input received: "+line);
                                }
                            }    
                        } catch (IllegalStateException isex) { 
                            // Log.v("eXport-it HttpSession","IllegalStateException InputStream waiting for input on request: "+isex);
                            if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;   
                        } catch (IOException ex) {
                            // Log.v("eXport-it HttpSession","IOexception InputStream waiting for input on request: "+ex);
                            if (is != null) {
                                try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;    
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession","exception InputStream waiting for input on request: "+ex);
                            if (is != null) {
                                try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;
                        }
                    }
                    lineNb = 0;
                    no_request = true;
                    statusLine = "";
                    HttpVersion = "";
                    SoapAction =  "";
                    connectionFound = false;
                    headerKey  = "";
                    headerValue  = "";
                    applicationUrl = "";
                    contentLength = "";
                    contentType = "";
                    soapActionFound = false;
                    contentLengthFound = false;
                    contentTypeFound = false;
                    requestHeadersReceived = false;
                    requestBodyReceived = false;
                    requestHeadersLength = 0;
                    requestBodyLength = 0;
                    requestMethod = "";
                    uri = "";
                    requestURI = "";
                    requestContentLength = 0;
                    String AV_Client = "";
                    String AV_PhysicalUnit = "";
                    reqHeaders = new UpnpHeaders();
                    requestHttpMinorVersion = 0;
                    
                    while (line != null) {
                        if (line.length() != 0) {
                            if (lineNb == 0) { // Status line
                                statusLine = line;    // status-line = HTTP-version SP status-code SP reason-phrase CRLF
                                String[] wrd = statusLine.split(" ");
                                if (wrd != null) {
                                    if (wrd.length > 1) {
                                        method = wrd[0];
                                        requestMethod = wrd[0];
                                        uri = wrd[1];
                                        requestURI = wrd[1];
                                        if (wrd.length > 1) {
                                            HttpVersion = wrd[2];
                                            if (HttpVersion != null) {
                                               Character last = HttpVersion.charAt(HttpVersion.length()-1);
                                               if (last.equals(new Character('1'))) {
                                                   requestHttpMinorVersion = 1;
                                               } else {
                                                   requestHttpMinorVersion = 0;
                                               }
                                            } else {
                                               requestHttpMinorVersion = 0;
                                            }
                                        }
                                        // Log.v("eXport-it HttpSession","Request message "+method+" "+uri+" "+HttpVersion);
                                        no_request = false;
                                    }
                                }
                            } else {
                                String[] wrd2 = line.split(" ");
                                if (wrd2 != null) {
                                    if (wrd2.length > 1) {
                                        headerKey = wrd2[0];
                                        headerKey = headerKey.replace(":","");
                                        int l = wrd2.length;
                                        headerValue = wrd2[1];
                                        for (int k=2; k < l; k++) {
                                            headerValue = headerValue + " " + wrd2[k];
                                        }
                                        if (headerKey.toUpperCase().equals("CONTENT-TYPE")) {
                                            contentType =  headerValue;
                                            contentTypeFound = true;
                                        } else {
                                            if (headerKey.toUpperCase().equals("APPLICATION-URL")) {
                                                applicationUrl =  headerValue; 
                                                // Log.v("eXport-it HttpSession","<application URL header found: "+applicationUrl);
                                            } else {
                                                if (headerKey.toUpperCase().equals("CONNECTION")) {
                                                    // Log.v("eXport-it HttpSession","Connection header found: "+headerValue);
                                                     if (headerValue.toLowerCase().equals("keep-alive")) { 
                                                         if (requestMethod.toUpperCase().equals("POST")) {
                                                             KeepAlive = true;
                                                         } 
                                                    }    
                                                    connectionFound = true; 
                                                } else {
                                                    if (headerKey.toUpperCase().equals("CONTENT-LENGTH")) {
                                                        contentLengthFound = true;
                                                        contentLength =  headerValue; 
                                                        try { requestContentLength = Integer.parseInt(contentLength);
                                                        } catch (NumberFormatException ex) { }
                                                    } else {
                                                        if (headerKey.toUpperCase().equals("SOAPACTION")) {
                                                            SoapAction =  headerValue; 
                                                            soapActionFound = true;
                                                        } else {
                                                            if (headerKey.toUpperCase().equals("HOST")) {
      
                                                            } else {
                                                                if (headerKey.toLowerCase().contains("x-av-client-info")) {
                                                                   AV_Client = headerValue;
                                                                } else {
                                                                   if (headerKey.toLowerCase().contains("x-av-physical-unit-info")) {
                                                                       AV_PhysicalUnit = headerValue;
                                                                    }
                                                                }
                                                            }
                                                        }    
                                                    }
                                                }
                                            }
                                        }
                                        reqHeaders.add(headerKey, headerValue);
                                    }
                                }
                            }
                            lineNb++;
                        } else {
                            if (lineNb == 0) {
                                // Log.v("eXport-it HttpSession","null line found, trying to read request!!!"); 
                            }
                            break; 
                        }
                        try {
                            line = br.readLine();
                        } catch (SocketException sex) {
                           // Log.v("eXport-it HttpSession","SocketException reading following Header Lines of request: "+sex); 
                           break;
                        } catch (IllegalStateException isex) { 
                           // Log.v("eXport-it HttpSession","IllegalStateException reading following Header Lines of request: "+isex);
                           if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                           }
                           KeepAlive = false;
                           return;   
                        } catch (IOException ex) {
                           // Log.v("eXport-it HttpSession","IOexception reading following Header Lines of request: "+ex);
                        } catch (Exception ex) {
                           // Log.v("eXport-it HttpSession","Exception reading following Header Lines of request: "+ex); 
                           if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                           }
                           KeepAlive = false;
                           return; 
                        }    
                    }
    
                    line = null;
                    try {
                        line = br.readLine();
                    } catch (SocketException sex) {
                        // Log.v("eXport-it HttpSession","SocketException reading initial Body line of request: "+sex);
                    } catch (IllegalStateException isex) { 
                        // Log.v("eXport-it HttpSession","IllegalStateException reading initial Body line of request: "+isex);
                        if (is != null) {
                           try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;   
                    } catch (IOException ex) {
                        // Log.v("eXport-it HttpSession","IOexception reading initial Body line of request: "+ex);
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession","exception reading initial Body line of request: "+ex);
                        if (is != null) {
                           try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;  
                    }
                    bodyString = "";
                    while ((line != null)  && (line.length() > 0)) {
                        bodyString = bodyString + line + "\r\n";
                        try {
                            line = br.readLine();
                        } catch (SocketException sex) {
                           // Log.v("eXport-it HttpSession","SocketException reading next Body line of request: "+sex);
                        } catch (IllegalStateException isex) { 
                           // Log.v("eXport-it HttpSession","IllegalStateException reading next Body line of request: "+isex);
                           if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                           }
                           KeepAlive = false;
                           return;     
                        } catch (IOException ex) {
                           // Log.v("eXport-it HttpSession","IOexception reading next Body line of request "+ex);
                        } catch (Exception ex) {
                           // Log.v("eXport-it HttpSession","Exception reading next Body line of request: "+ex);
                           if (is != null) {
                               try { is.close(); } catch (IOException ioe) {  }
                           }
                           KeepAlive = false;
                           return;  
                        }
                    }
                    if (bodyString != null) { 
                        requestBodyLength = bodyString.length();
                    } else { 
                        requestBodyLength = 0;
                    } 

                if ((method == null) || (uri == null) || (method == "") || (uri == "")) {
                    if (is != null) {
                        try { is.close(); } catch (IOException ex) {  }
                    }
                    KeepAlive = false;
                    return;
                }

                URI u = null;
                if (uri != null) {
                    try {
                        u = new URI(requestURI);
                    } catch (URISyntaxException uex) {
                        if (is != null) {
                            try { is.close(); } catch (IOException ex) {  }
                        }
                        KeepAlive = false;
                        return;
                    } catch (Exception ex) {
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }
                } 
                if (u == null) {
                    if (is != null) {
                        try { is.close(); } catch (IOException ioe) {  }
                    }
                    KeepAlive = false;
                    return;
                }

                // if (requestMethod.toUpperCase().equals("POST")) {
                    // nLog.v("eXport-it HttpSession "," content-size:"+contentLength+"  content-Type:"+contentType+"  SoapAction:"+SoapAction);
                // } 

                try {
                    if (bodyString.length() > 0) {
                        // Log.v("eXport-it HttpSession ","request body: "+bodyString);
            	        requestMessage = new StreamRequestMessage(UpnpRequest.Method.getByHttpName(requestMethod), URI.create(requestURI),bodyString);
                    } else {
                        requestMessage = new StreamRequestMessage(UpnpRequest.Method.getByHttpName(requestMethod), URI.create(requestURI));
                    }
                } catch (IllegalArgumentException e) {
                    String msg = "Invalid request URI: " + requestURI + ": " + e.getMessage();
            	    // Log.v("eXport-it HttpSession ","StreamRequestMessage IllegalArgumentException "+msg);
                }
            
                if (requestMessage != null) {
                    /* if (requestMethod.toUpperCase().equals("POST")) {
                          Log.v("eXport-it HttpSession "," POST request URI: " + uri);
                          for (final String name: header.stringPropertyNames()) {
                              Log.v("eXport-it HttpSession ","  POST request HDR: " + name + " " + header.getProperty( name ));
                          }
                    } */
                    if (reqHeaders != null) {
                        upnpHeaders = reqHeaders;
                    } else {
                        upnpHeaders = new UpnpHeaders();
                    }    
                    if (!requestMessage.getOperation().getMethod().equals(UpnpRequest.Method.UNKNOWN)) {
                        // HTTP version
                        requestOperation = requestMessage.getOperation();
                        requestMessage.getOperation().setHttpMinorVersion(requestHttpMinorVersion);
                        // Headers
                        /* if (!upnpHeaders.containsKey(UpnpHeader.Type.HOST)) {
                               upnpHeaders.add("Host", host+":"+port);
                        } */
                        if (requestMethod.toUpperCase().equals("POST")) {
                            int lng = 0;
                            try {
                                byte[] BodyByte = bodyString.getBytes("UTF-8");
                                lng = BodyByte.length;
                            } catch (UnsupportedEncodingException e) {
                            }
                            if (!soapActionFound) {
                                upnpHeaders.add("SoapAction", "urn:schemas-upnp-org:service:ContentDirectory:1#Browse");
                            }
                            if (!contentTypeFound) {
                                upnpHeaders.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                            }
                            if (!contentLengthFound) {
                                upnpHeaders.add("Content-Length", String.valueOf(lng));
                            }
                            // Log.v("eXport-it HttpSession ","request body length: "+bodyString.length()+"/"+lng+" content-length:"+contentLength);
                            // Log.v("eXport-it HttpSession "," POST request Body "+bodyString);
                        } 
                        
                        requestMessage.setHeaders(upnpHeaders);
                        // Body
                        requestMessage.setBody(UpnpMessage.BodyType.STRING, bodyString);
                        
                        if (bodyString.contains("X_GetFeatureList")==true) {
                            String responseText = getFeatureList();
                            UpnpHeaders headers = new UpnpHeaders();
                            headers.add(UpnpHeader.Type.SERVER, new ServerHeader());
                            headers.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                            headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                            String HeadersStr = headers.toString();
                            byte[] headerBytes = null;
                            try {
                                headerBytes = HeadersStr.getBytes("UTF-8");      // @@@  ()
                            } catch (UnsupportedEncodingException uee) {
                                // Log.v("eXport-it HttpSession ","UnsupportedEncodingException in HeadersStr.getBytes: "+uee);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }   catch (Exception ex) {
                                // Log.v("eXport-it HttpSession ","Exception in HeadersStr.getBytes: "+ex);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }
                            if (headerBytes == null) {
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }   
                            ByteArrayInputStream inputStr;
                            inputStr = new ByteArrayInputStream(headerBytes);    // bodyBytes2
                            headers = new UpnpHeaders(inputStr);
                            String headersString = headers.toString();
                            String responseEntity = responseText;
                            responseMsg = new StreamResponseMessage(responseText);
                            HeaderUtil.add(responseMsg, headers); 
                            alreadyDone = true;
                        } else {
                            if (bodyString.contains("X_SetBookmark")==true) {
                                String responseText = SetBookmark();
                                UpnpHeaders headers = new UpnpHeaders();
                                headers.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                                headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                                String HeadersStr = headers.toString();
                                byte[] headerBytes = null;
                                try {
                                    headerBytes = HeadersStr.getBytes("UTF-8");      // @@@  ()
                                } catch (UnsupportedEncodingException uee) {
                                    // Log.v("eXport-it HttpSession ","UnsupportedEncodingException in HeadersStr.getBytes: "+uee);
                                    if (is != null) {
                                        try { is.close(); } catch (IOException ioe) {  }
                                    }
                                    KeepAlive = false;
                                    return;
                                }   catch (Exception ex) {
                                    // Log.v("eXport-it HttpSession ","Exception in HeadersStr.getBytes: "+ex);
                                    if (is != null) {
                                        try { is.close(); } catch (IOException ioe) {  }
                                    }
                                    KeepAlive = false;
                                    return;
                                }
                                if (headerBytes == null) {
                                    if (is != null) {
                                        try { is.close(); } catch (IOException ioe) {  }
                                    }
                                    KeepAlive = false;
                                    return;
                                }
                                ByteArrayInputStream inputStr;
                                inputStr = new ByteArrayInputStream(headerBytes);    // bodyBytes2
                                headers = new UpnpHeaders(inputStr);
                                responseMsg = new StreamResponseMessage(responseText);
                                HeaderUtil.add(responseMsg, headers);
                                alreadyDone = true;                          
                            } else {
                                /* if ((AV_PhysicalUnit.length() > 1) && (AV_Client.length() > 1)) {
                                    String responseText = SetBookmark();
                                    UpnpHeaders headers = new UpnpHeaders();
                                    headers.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                                    headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                                    String HeadersStr = headers.toString();
                                    byte[] headerBytes;
                                    headerBytes = HeadersStr.getBytes("UTF-8");      
                                    ByteArrayInputStream inputStr;
                                    inputStr = new ByteArrayInputStream(headerBytes);    
                                    headers = new UpnpHeaders(inputStr);
                                    responseMsg = new StreamResponseMessage(responseText);
                                    HeaderUtil.add(responseMsg, headers);
                                    alreadyDone = true;      
                                } */              
                            } 
                        }                     

                        // Finally process it
                        responseMsg = null;
                        if (!alreadyDone) {            
                           try {
                               /* UpnpHeaders upnpHeaders2 = requestMessage.getHeaders();
                               if (!upnpHeaders2.containsKey(UpnpHeader.Type.CONTENT_TYPE)) {
                                   upnpHeaders2.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                                   // upnpHeaders2.add(UpnpHeader.Type.SERVER, new ServerHeader());
                                   // upnpHeaders2.add(UpnpHeader.Type.EXT, new EXTHeader()); 
                                } */
                                requestMessage.setHeaders(upnpHeaders);
                                responseMsg = process(requestMessage);
                            } catch (RuntimeException ex) {
                                // Log.v("eXport-it HttpSession","Exception occured during UPnP stream processing: " + ex);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }
                        }
                    }
                    
                    if (responseMsg == null) {
                        if (is != null) {
                            try { is.close(); } catch (IOException ioe) {  }
                        }
                        KeepAlive = false;
                        return;
                    }
                    loop++;

                    int udaMajorVersion = 1;
                    int udaMinorVersion = 0;

                    UpnpHeaders headers = new UpnpHeaders();
                    Object body;
                    UpnpMessage.BodyType bodyType = responseMsg.getBodyType();
                    UpnpOperation operation = responseMsg.getOperation();
                    // Properties pre2 = new Properties();
	            // Properties parms2 = new Properties();
	            // Properties header2 = new Properties();
	            // Properties files2 = new Properties();
                    int statuscode = 200;
                    String statusMsg = "OK";
                    String bodyString2 = "";
                    byte[] bodyBytes2 = new byte[bufsize];

                       statuscode = responseMsg.getOperation().getStatusCode();
                       statusMsg = responseMsg.getOperation().getStatusMessage();
                       // Log.v("eXport-it HttpSession","Response RC: " + statuscode + "status Msg: " + statusMsg);
                       headers = responseMsg.getHeaders();
                       /* if (!headers.containsKey(UpnpHeader.Type.CONTENT_TYPE)) {
                           // Log.v("eXport-it HttpSession","Response NO Content-Type");
                           headers.add(UpnpHeader.Type.CONTENT_TYPE, new ContentTypeHeader());
                       } */
                       if (!headers.containsKey(UpnpHeader.Type.SERVER)) {
                           // Log.v("eXport-it HttpSession","Response NO Server");
                           headers.add(UpnpHeader.Type.SERVER, new ServerHeader());
                        } 
                        // if (!headers.containsKey(UpnpHeader.Type.EXT)) {
                           // Log.v("eXport-it HttpSession","Response NO Ext");
                        //   headers.add(UpnpHeader.Type.EXT, new EXTHeader());
                        //}    
                        bodyType = responseMsg.getBodyType();
                        // Log.v("eXport-it HttpSession","Response to "+requestMessage.getUri().toString()+"bodyType: "+bodyType+" headers: "+headers.size());
                        if (responseMsg.hasBody()) {
                            if (responseMsg.getBodyType() == UpnpMessage.BodyType.STRING) {
                               bodyString2 = responseMsg.getBodyString();
                               if (bodyString2 == null) {
                                   bodyString2 = "";
                               }
                            } else {
                               bodyBytes2 = responseMsg.getBodyBytes();
                               if (bodyBytes2 == null) {
                                   bodyBytes2 = new byte[0];
                               }
                            }
                        }
                        udaMajorVersion = responseMsg.getUdaMajorVersion();
                        udaMinorVersion = responseMsg.getUdaMinorVersion();
                        if ((mySocket == null) || (mySocket.isClosed())) {
                            KeepAlive = false;
                            return;
                        } 
                        if (out == null) {
                            try {
                                out = mySocket.getOutputStream();
                            } catch (IOException ioe) {
                                // Log.v("eXport-it HttpSession ","IOException in getOutputStream: "+ioe);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ex) {  }
                                }
                                KeepAlive = false;
                                return;
                            }   catch (Exception ex) {
                                // Log.v("eXport-it HttpSession ","Exception in getOutputStream: "+ex);
                                if (is != null) {
                                    try { is.close(); } catch (IOException ioe) {  }
                                }
                                KeepAlive = false;
                                return;
                            }
                        }
                        if (out == null) {
                            if (is != null) {
                                try { is.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;
                        }
	                // PrintWriter pw = new PrintWriter( out );
                        // BufferedWriter bw = null;
                        PrintWriter pw = null;
                        try {
                            // bw = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
                           // bw = new PrintStream(out, false,"UTF-8");
                           OutputStreamWriter osw = new OutputStreamWriter(out, "UTF-8");
                           BufferedWriter bw = new BufferedWriter(osw);
                           pw = new PrintWriter(bw,true);
                        } catch (UnsupportedEncodingException uee) {
                            // Log.v("eXport-it HttpSession"," UnsupportedEncodingException creating PrintStream "+uee);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return; 
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession"," Exception creating PrintWriter "+ex);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;  
                        }
                        if (pw == null) {
                            // Log.v("eXport-it HttpSession"," Buffered Print Writer pw is NULL!!!");
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;  
                        }
                        try {
		            pw.print("HTTP/1."+udaMinorVersion+" " + statuscode + " " + statusMsg + " \r\n");
		            java.text.SimpleDateFormat gmtFrmt = null;
                            gmtFrmt = new java.text.SimpleDateFormat( "E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
	                    gmtFrmt.setTimeZone(TimeZone.getTimeZone("GMT"));
                            if (gmtFrmt != null) {
                               pw.print( "Date: " + gmtFrmt.format( new Date()) + "\r\n");
                            }
                            String HeadersStr = "";
		            if (headers != null ) {
                                HeadersStr = headers.toString();
                                /* if (requestMethod.toUpperCase().equals("POST")) {
                                    Log.v("eXport-it HttpSession","Response Headers: "+HeadersStr);
                                } */
	                    }
                            pw.print(HeadersStr);
                            if (KeepAlive) {
                                pw.print("Connection: keep-alive\r\n");
                            } else {
                               pw.print("Connection: close\r\n");
                            }
                            // bw.print("Content-Type: text/xml; charset=UTF-8\r\n");
                            if (SoapAction != null) {
                                if (SoapAction.length() > 1) {
                                    pw.print("SOAPAction: " + SoapAction + "\r\n");
                                    // Log.v("eXport-it HttpSession","Response Headers: "+"SOAPAction: " + SoapAction);
                                } 
                            }
                            int lng =  0;
                            byte[] BodyBytes = new byte[100];
                            if (bodyString2 != null) {
                                if (bodyString2.length() > 0) {
                                    try {
                                        BodyBytes = bodyString2.getBytes("UTF-8");
                                        lng = BodyBytes.length + 2;
                                    } catch (UnsupportedEncodingException e) {
                                        // Log.v("eXport-it HttpSession","Response Body Length EncodingException: "+e);
                                        KeepAlive = false;
                                        return;
                                    }
                                    pw.print("Content-Length: "+lng + "\r\n");
                                    // Log.v("eXport-it HttpSession","Response Headers: "+"Content-Length: "+lng);
                                } else {
                                    if (bodyBytes2.length > 0) {
                                        BodyBytes = bodyBytes2;
                                        lng = BodyBytes.length + 2;
                                        try {
                                            bodyString2 = new String(bodyBytes2, "UTF-8");
                                        } catch (UnsupportedEncodingException uee) {
                                            // Log.v("eXport-it HttpSession","Response Body Bytes EncodingException: "+uee);
                                            KeepAlive = false;
                                            return;
                                        }
                                        if (lng > 0) {
                                            pw.print("Content-Length: "+lng + "\r\n");
                                            // Log.v("eXport-it HttpSession","Response Headers: "+"Content-Length: "+lng);
                                        } else {
                                            pw.print("Content-Length: 0\r\n");
                                        }
                                    }  
                                }
                                pw.print("user-agent: Linux/3.18.91-14843133-QB28034466 UPnP/1.0 DLNADOC/1.50 eXport-it/1.0\r\n");
                                pw.print("\r\n");
                                if (lng > 0) {
                                    pw.print(bodyString2);
                                    pw.print("\r\n");
                                    if (requestMethod.toUpperCase().equals("POST")) {
                                        // Log.v("eXport-it HttpSession","Response Body length: "+bodyString2.length()+"/"+lng+" "+bodyString2);
                                    } 
                                }
                            } else {
		                pw.print("\r\n");
                            }
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession ","Exception in writing pw: "+ex);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;    
                        }   
                        // Log.v("eXport-it HttpSession","Response RC: " + statuscode + " status Msg: " + statusMsg+"  body length: "+bodyString2.length());
                        try {
                            pw.flush();
                        } catch (Exception ex) {
                            // Log.v("eXport-it HttpSession ","Exception in flushing pw: "+ex);
                            if (out != null) {
                                try { out.close(); } catch (IOException ioe) {  }
                            }
                            KeepAlive = false;
                            return;    
                        }   
                        if (!KeepAlive) {
                            try {
                                if (requestMethod.toUpperCase().equals("POST")) {
                                    try {
                                        Thread.sleep(3000);
                                    } catch (InterruptedException iex) {
                                    }
                                } else {
                                    try {
                                        Thread.sleep(1000);
                                    } catch (InterruptedException iex) {
                                    }
                                }
                                if (pw != null) pw.close();
                                if (out != null) out.close();
                            } catch (IOException ioe) {
                                // Log.v("eXport-it HttpSession ","IOException in closing out: "+ioe);
                                KeepAlive = false;
                                return;    
                            } catch (Exception ex) {
                                // Log.v("eXport-it HttpSession "," Exception closing out: "+ex);
                                KeepAlive = false;
                                return;   
                            }
                        }
                    }
                }

                if (!KeepAlive) {
                    try {
	                if (is != null) {
                            if (requestMethod.toUpperCase().equals("POST")) {
                                try {
                                    Thread.sleep(3000);
                                } catch (InterruptedException iex) {
                                }
                            } else {
                                try {
                                    Thread.sleep(1000);
                                } catch (InterruptedException iex) {
                                }
                            }
                            is.close();
                        }
                    } catch (IOException ioe) {
                        // Log.v("eXport-it HttpSession ","IOException in closing in: "+ioe);
                        KeepAlive = false;
                    } catch (Exception ex) {
                        // Log.v("eXport-it HttpSession "," Exception closing in: "+ex);
                        KeepAlive = false;
                    }
                    if ((mySocket != null) && (!mySocket.isClosed())) {
                            if (requestMethod.toUpperCase().equals("POST")) {
                                try {
                                    Thread.sleep(2000);
                                } catch (InterruptedException iex) {
                                }
                            } else {
                                try {
                                    Thread.sleep(1000);
                                } catch (InterruptedException iex) {
                                }
                            }
	                try { mySocket.close(); } catch(Exception ex2) {
                            KeepAlive = false;
                        } 
                    }   
                } else {
                    try {
                       Thread.sleep(100);
                    } catch (InterruptedException iex) {
                        
                    }
                }
            }
           
 
        if (mySocket != null) {
            if (!mySocket.isClosed()) {
                try {
                    Thread.sleep(1000);
                    mySocket.close();
                } catch (InterruptedException iex) {
                } catch (Exception ex) { }
            }
        }
        return;
        
    }    

    /**
     * Find byte index separating header from body.
     * It must be the last byte of the first two sequential new lines.
     **/
    private int findHeaderEnd(final byte[] buf, int rlen) {
	int splitbyte = 0;
        if (buf.length < rlen) { rlen = buf.length; }
	while (splitbyte + 3 < rlen) 	{
	    if (buf[splitbyte] == '\r' && buf[splitbyte + 1] == '\n' && buf[splitbyte + 2] == '\r' && buf[splitbyte + 3] == '\n') {
		return splitbyte + 4;
	    }	
	    splitbyte++;
	}
	return 0;
    }

    /**
     * Decodes the percent encoding scheme. <br/>
     * For example: "an+example%20string" -> "an example string"
     */
    private String decodePercent( String str ) {
	try {		
            StringBuffer sb = new StringBuffer();
	    for( int i=0; i<str.length(); i++ ) {
		char c = str.charAt( i );
		switch ( c ) {
		    case '+':
			sb.append( ' ' );
			break;
		    case '%':
			sb.append((char)Integer.parseInt( str.substring(i+1,i+3), 16 ));
			i += 2;
			break;
		    default:
			sb.append( c );
		        break;
		}
	    }
	    return sb.toString();
	} catch( Exception e) {
	    // sendError( HTTP_BADREQUEST, "BAD REQUEST: Bad percent-encoding." );
	    return null;
	}
    }

    /**
     * Decodes parameters in percent-encoded URI-format
     * ( e.g. "name=Jack%20Daniels&pass=Single%20Malt" ) and
     * adds them to given Properties. NOTE: this doesn't support multiple
     * identical keys due to the simplicity of Properties -- if you need multiples,
     * you might want to replace the Properties with a Hashtable of Vectors or such.
     */
    private void decodeParms( String parms, Properties p ) {
	if ( parms == null ) {
		return;
        }
	StringTokenizer st = new StringTokenizer( parms, "&" );
	while ( st.hasMoreTokens()) {
		String e = st.nextToken();
		int sep = e.indexOf( '=' );
		if ( sep >= 0 ) {
			p.put( decodePercent( e.substring( 0, sep)).trim(), decodePercent( e.substring( sep+1)));
		} else {
			p.put( decodePercent( e ).trim(), "" );
		}	
	}
    }
    
    /**
     * URL-encodes everything between "/"-characters. Encodes spaces as '%20'
     * instead of '+'.
     */
    private String encodeUri(String uri) {
        String newUri = "";
        StringTokenizer st = new StringTokenizer(uri, "/ ", true);
        while (st.hasMoreTokens()) {
            String tok = st.nextToken();
            if (tok.equals("/")) {
                newUri += "/";
            } else if (tok.equals(" ")) {
                newUri += "%20";
            } else {
                // newUri += URLEncoder.encode(tok);
                try { newUri += URLEncoder.encode( tok, "UTF-8" ); } catch ( java.io.UnsupportedEncodingException uee ) {}
                // For Java 1.4 you'll want to use this instead:
                // try { newUri += URLEncoder.encode( tok, "UTF-8" ); } catch ( java.io.UnsupportedEncodingException uee ) {}
            }
        }
        return newUri;
    }   
    
    synchronized public StreamResponseMessage process(StreamRequestMessage requestMsg) {
        // Log.v("eXport-it HttpSession","Processing stream request message: " + requestMsg);
        
        try {
            // Try to get a protocol implementation that matches the request message
            syncProtocol = router.getProtocolFactory().createReceivingSync(requestMsg);
        } catch (Exception ex) {
            // Log.v("eXport-it HttpSession","Exception for defining synchronous message processing: " + ex);
        }            
        // Log.v("eXport-it HttpSession","Running protocol for synchronous message processing: " + syncProtocol);
        syncProtocol.run();

        // ... then grab the response
        StreamResponseMessage responseMsg = syncProtocol.getOutputMessage();

        if (responseMsg == null) {
            // That's ok, the caller is supposed to handle this properly (e.g. convert it to HTTP 404)
            // Log.v("eXport-it HttpSession","Protocol did not return any response message");
            return null;
        }
        // Log.v("eXport-it HttpSession","Protocol returned response: " + responseMsg);
        return responseMsg;
    }
        
    public String getFeatureList() {
        String resp ="<s:Envelope xmlns:s=\"http://schemas.xmlsoap.org/soap/envelope/\" s:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"+
            "<s:Body>"+
            "<u:X_GetFeatureListResponse xmlns:u=\"urn:schemas-upnp-org:service:ContentDirectory:1\">"+
            "<FeatureList>"+
            "<?xml version=\"1.0\" encoding=\"utf-8\"?>\r\n"+
            "&lt;Features xmlns=\"urn:schemas-upnp-org:av:avs\""+
            " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""+
            " xsi:schemaLocation=\"urn:schemas-upnp-org:av:avs http://www.upnp.org/schemas/av/avs.xsd\"&gt;"+
            "&lt;Feature name=\"samsung.com_BASICVIEW\" version=\"1\"&gt;"+
            "&lt;container id=\"1\" type=\"object.item.videoItem\"/&gt;"+             
            "&lt;container id=\"2\" type=\"object.item.audioItem\"/&gt;"+
            "&lt;container id=\"3\" type=\"object.item.imageItem\"/&gt;"+
            "&lt;/Feature&gt;"+
            "</FeatureList></u:X_GetFeatureListResponse>"+
            "</s:Body>"+
            "</s:Envelope>";
        return resp;
    }       
    
    public String SetBookmark() {
        String resp = "<s:Envelope xmlns:s=\"http://schemas.xmlsoap.org/soap/envelope/\" s:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"+
            "<s:Body>"+
            "<u:X_SetBookmarkResponse"+
            " xmlns:u=\"urn:schemas-upnp-org:service:ContentDirectory:1\">"+
            "</u:X_SetBookmarkResponse> 1 1"+
            "</s:Body>"+
            "</s:Envelope>";    
        return resp;
    } 

    public InputStream getData() {
        return this.data;
    }

    public String getMimeType() {
        return this.mimeType;
    }

    public String getRequestMethod() {
        return this.method;
    }

    public void setKeepAlive(boolean useKeepAlive) {
        this.keepAlive = useKeepAlive;
    }

    public void setData(InputStream data) {
        this.data = data;
    }

    public void setMimeType(String mimeType) {
        this.mimeType = mimeType;
    }

    public void setRequestMethod(String requestMethod) {
        this.method = requestMethod;
    }

    public void setStatus(String status) {
        this.status = status;
    }
    
}
  
